==> SQLiteCSLib_Src_1_4.zip: SQLiteCSLib_Src_1_4/1.x/TestApp/TestForm.cs <==
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

using SQLiteCSLib;
using SQLiteCSLib.Inner;

namespace TestApp
{
	/// <summary>
	/// CueXgptH[
	/// </summary>
	public class TestForm : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Button button1;
		private System.Windows.Forms.Button button2;
		private System.Windows.Forms.Button button3;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Button button4;
		private System.Windows.Forms.DataGrid dataGrid1;
		private System.Windows.Forms.DataGridTableStyle dataGridTableStyle1;
		private SQLiteCSLib.SQLiteDataAdapter sqLiteDataAdapter1;
		private SQLiteCSLib.SQLiteCommand sqLiteCommand1;
		private SQLiteCSLib.SQLiteConnection sqLiteConnection1;
		private SQLiteCSLib.SQLiteTransaction sqLiteTransaction1;
		private TestApp.Dataset1 dataset11;
		private System.Windows.Forms.Button button5;

		/// <summary>
		/// KvȃfUCiϐłB
		/// </summary>
		private System.ComponentModel.Container components = null;

		/// <summary>
		/// RXgN^
		/// </summary>
		public TestForm()
		{
			InitializeComponent();
		}

		/// <summary>
		/// gpĂ郊\[XɌ㏈s܂B
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows tH[ fUCiŐꂽR[h 
		/// <summary>
		/// fUCi T|[gɕKvȃ\bhłB̃\bh̓e
		/// R[h GfB^ŕύXȂłB
		/// </summary>
		private void InitializeComponent()
		{
			this.button1 = new System.Windows.Forms.Button();
			this.button2 = new System.Windows.Forms.Button();
			this.button3 = new System.Windows.Forms.Button();
			this.label1 = new System.Windows.Forms.Label();
			this.button4 = new System.Windows.Forms.Button();
			this.dataGrid1 = new System.Windows.Forms.DataGrid();
			this.dataset11 = new TestApp.Dataset1();
			this.dataGridTableStyle1 = new System.Windows.Forms.DataGridTableStyle();
			this.sqLiteDataAdapter1 = new SQLiteCSLib.SQLiteDataAdapter();
			this.sqLiteCommand1 = new SQLiteCSLib.SQLiteCommand();
			this.sqLiteConnection1 = new SQLiteCSLib.SQLiteConnection();
			this.sqLiteTransaction1 = new SQLiteCSLib.SQLiteTransaction();
			this.button5 = new System.Windows.Forms.Button();
			((System.ComponentModel.ISupportInitialize)(this.dataGrid1)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.dataset11)).BeginInit();
			this.SuspendLayout();
			// 
			// button1
			// 
			this.button1.Location = new System.Drawing.Point(16, 24);
			this.button1.Name = "button1";
			this.button1.TabIndex = 0;
			this.button1.Text = "button1";
			this.button1.Click += new System.EventHandler(this.button1_Click);
			// 
			// button2
			// 
			this.button2.Location = new System.Drawing.Point(16, 72);
			this.button2.Name = "button2";
			this.button2.TabIndex = 1;
			this.button2.Text = "button2";
			this.button2.Click += new System.EventHandler(this.button2_Click);
			// 
			// button3
			// 
			this.button3.Location = new System.Drawing.Point(120, 24);
			this.button3.Name = "button3";
			this.button3.TabIndex = 2;
			this.button3.Text = "button3";
			this.button3.Click += new System.EventHandler(this.button3_Click);
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(120, 64);
			this.label1.Name = "label1";
			this.label1.TabIndex = 3;
			this.label1.Text = "label1";
			// 
			// button4
			// 
			this.button4.Location = new System.Drawing.Point(16, 128);
			this.button4.Name = "button4";
			this.button4.TabIndex = 4;
			this.button4.Text = "button4";
			this.button4.Click += new System.EventHandler(this.button4_Click);
			// 
			// dataGrid1
			// 
			this.dataGrid1.DataMember = "";
			this.dataGrid1.DataSource = this.dataset11;
			this.dataGrid1.HeaderForeColor = System.Drawing.SystemColors.ControlText;
			this.dataGrid1.Location = new System.Drawing.Point(56, 216);
			this.dataGrid1.Name = "dataGrid1";
			this.dataGrid1.Size = new System.Drawing.Size(376, 160);
			this.dataGrid1.TabIndex = 5;
			this.dataGrid1.TableStyles.AddRange(new System.Windows.Forms.DataGridTableStyle[] {
																								  this.dataGridTableStyle1});
			// 
			// dataset11
			// 
			this.dataset11.DataSetName = "Dataset1";
			this.dataset11.Locale = new System.Globalization.CultureInfo("en-US");
			// 
			// dataGridTableStyle1
			// 
			this.dataGridTableStyle1.DataGrid = this.dataGrid1;
			this.dataGridTableStyle1.HeaderForeColor = System.Drawing.SystemColors.ControlText;
			this.dataGridTableStyle1.MappingName = "";
			// 
			// sqLiteDataAdapter1
			// 
			this.sqLiteDataAdapter1.DeleteCommand = null;
			this.sqLiteDataAdapter1.InsertCommand = null;
			this.sqLiteDataAdapter1.SelectCommand = this.sqLiteCommand1;
			this.sqLiteDataAdapter1.UpdateCommand = null;
			// 
			// sqLiteCommand1
			// 
			this.sqLiteCommand1.CommandText = "select * from tb2";
			this.sqLiteCommand1.CommandTimeout = 0;
			this.sqLiteCommand1.CommandType = System.Data.CommandType.Text;
			this.sqLiteCommand1.Connection = this.sqLiteConnection1;
			this.sqLiteCommand1.Transaction = this.sqLiteTransaction1;
			this.sqLiteCommand1.UpdatedRowSource = System.Data.UpdateRowSource.None;
			// 
			// sqLiteConnection1
			// 
			this.sqLiteConnection1.ConnectionString = "test.sqlite3";
			// 
			// sqLiteTransaction1
			// 
			this.sqLiteTransaction1.Connect = this.sqLiteConnection1;
			// 
			// button5
			// 
			this.button5.Location = new System.Drawing.Point(312, 80);
			this.button5.Name = "button5";
			this.button5.TabIndex = 6;
			this.button5.Text = "button5";
			this.button5.Click += new System.EventHandler(this.button5_Click);
			// 
			// TestForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 12);
			this.ClientSize = new System.Drawing.Size(472, 414);
			this.Controls.Add(this.button5);
			this.Controls.Add(this.dataGrid1);
			this.Controls.Add(this.button4);
			this.Controls.Add(this.label1);
			this.Controls.Add(this.button3);
			this.Controls.Add(this.button2);
			this.Controls.Add(this.button1);
			this.Name = "TestForm";
			this.Text = "Form1";
			((System.ComponentModel.ISupportInitialize)(this.dataGrid1)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.dataset11)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// {^1
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button1_Click(object sender, System.EventArgs e)
		{
			try
			{
				using( SQLiteConnection db = new SQLiteConnection("test.sqlite3") )
				{
					db.Open();

					IDbCommand cmd = db.CreateCommand();
					//					cmd.CommandText = "CREATE TABLE tb1 ( pid INTEGER PRIMARY KEY, bin blob )";
					//					object res = cmd.ExecuteScalar();

					/*
										IDbTransaction tran = db.BeginTransaction();

										for( int iIdx=5; iIdx<6; iIdx++ )
										{
											cmd.Parameters.Clear();

											SQLiteParameter idp = cmd.CreateParameter() as SQLiteParameter;
											idp.ParameterName = ":id";
											idp.Value = iIdx;
											idp.Order = 0;
											cmd.Parameters.Add( idp );
											idp = cmd.CreateParameter() as SQLiteParameter;
											idp.ParameterName = ":bin";
											idp.Value = new byte[]{0x01, 0x02, 0x03};
											idp.Order = 1;
											cmd.Parameters.Add( idp );

											cmd.CommandText = "INSERT INTO tb1( pid, bin ) values( ?, ? )";
											cmd.ExecuteNonQuery();
										}

										tran.Commit();
					*/
					cmd.CommandText = "SELECT * FROM tb1 ";

					//					cmd.Parameters.Clear();
					/*
										SQLiteParameter idp = cmd.CreateParameter() as SQLiteParameter;
										idp.Value = "ii";
										idp.Order = 0;
										cmd.Parameters.Add( idp );
					*/

					using( IDataReader reader = cmd.ExecuteReader() )
					{
						//						DataTable dt = reader.GetSchemaTable();



						while( reader.Read() == true )
						{
							object c1 = reader.GetValue( 0 );
							object c2 = reader.GetValue( 1 );

							int a=2;

						}
					}

				}

			}
			catch( Exception ex )
			{
				string mes = ex.Message;
			}
		}

		#region [U`֐eXg

		/// <summary>
		/// XJ[p
		/// </summary>
		protected class ScalarFunc : SQLiteCSLib.Inner.IScalarCallUserFunction
		{
			/// <summary>
			/// ֐R[obN
			/// </summary>
			/// <param name="args"></param>
			public object CallFunc( object[] args )
			{
				foreach( object arg in args )
				{
					if( arg != null )
						Console.Write( arg.ToString() );
				}

				return 1;
			}
		};

		/// <summary>
		/// Wp
		/// </summary>
		protected class AggregateFunc : SQLiteCSLib.Inner.IAggregateCallUserFunction
		{
			/// <summary>
			/// ֐R[obN
			/// </summary>
			/// <param name="args"></param>
			public void CallStep( object[] args )
			{
				foreach( object arg in args )
				{
					if( arg != null )
						Console.Write( arg.ToString() );
				}
			}

			/// <summary>
			/// ֐R[obN
			/// </summary>
			public object CallFinal()
			{
				double dVal = 5.6;

				return dVal;
			}
		};
		#endregion

		/// <summary>
		/// {^2
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button2_Click(object sender, System.EventArgs e)
		{
			label1.Text = "";
			try
			{
				using( SQLiteConnection db = new SQLiteConnection("test.sqlite3") )
				{
					db.Open();

					//[U`֐
					ScalarFunc scalarfunc = new ScalarFunc(); 
					AggregateFunc aggregatefunc = new AggregateFunc();

					//[U`֐o^
					SQLiteCSLib.Inner.ResultEnum rest = db.CreateFunction("SCALAR1", 2, scalarfunc);
					rest = db.CreateFunction("AGGREGATE1", 2, aggregatefunc);

					IDbCommand cmd = db.CreateCommand();
					cmd.CommandText = "SELECT SCALAR1( pid, bin ),AGGREGATE1( 'Ă', null )  FROM tb1 ";

					using( IDataReader reader = cmd.ExecuteReader() )
					{
						while( reader.Read() == true )
						{
							object c1 = reader.GetValue( 0 );
							object c2 = reader.GetValue( 1 );

							label1.Text = string.Format(" {0},{1}",c1,c2 );
						}
					}
				}

			}
			catch( Exception ex )
			{
				string mes = ex.Message;
				label1.Text = mes;
			}		
		}

		/// <summary>
		/// {^3
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button3_Click(object sender, System.EventArgs e)
		{
			try
			{
				using( SQLiteConnection db = new SQLiteConnection("test.sqlite3") )
				{
					db.Open();

					IDbCommand cmd = db.CreateCommand();
					cmd.CommandText = "CREATE TABLE tb1 ( pid INTEGER PRIMARY KEY, bin blob )";
					object res = cmd.ExecuteScalar();
					
					IDbTransaction tran = db.BeginTransaction();

					for( int iIdx=6; iIdx<100; iIdx++ )
					{
						cmd.Parameters.Clear();

						SQLiteParameter idp = cmd.CreateParameter() as SQLiteParameter;
						idp.ParameterName = ":id";
						idp.Value = iIdx;
						idp.Order = 0;
						cmd.Parameters.Add( idp );
						idp = cmd.CreateParameter() as SQLiteParameter;
						idp.ParameterName = ":bin";
						idp.Value = new byte[]{0x01, 0x02, 0x03};
						idp.Order = 1;
						cmd.Parameters.Add( idp );

						cmd.CommandText = "INSERT INTO tb1( pid, bin ) values( ?, ? )";
						cmd.ExecuteNonQuery();
					}

					tran.Commit();
				}

			}
			catch( Exception ex )
			{
				string mes = ex.Message;
			}		
		}

		#region [U`ƍ
		/// <summary>
		/// XJ[p
		/// </summary>
		protected class CollationEx : SQLiteCSLib.Inner.ICollationFunction
		{
			/// <summary>
			/// r
			/// </summary>
			/// <param name="key1">rL[1</param>
			/// <param name="key2">rL[2</param>
			/// <returns> -1,0,1</returns>
			public int Compare( string key1, string key2 )
			{
				if( key1 == "" )
					return 1;

				if( key2 == "" )
					return -1;

				return key1.CompareTo( key2 );
			}
		};

		#endregion

		/// <summary>
		/// {^4
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button4_Click(object sender, System.EventArgs e)
		{

			label1.Text = "";
			try
			{
				using( SQLiteConnection db = new SQLiteConnection("test.sqlite3") )
				{
					db.Open();

					IDbCommand cmdx = db.CreateCommand();
//					cmdx.CommandText = "CREATE TABLE tb2 ( pid INTEGER PRIMARY KEY, name TEXT )";
//					object res = cmdx.ExecuteScalar();

					cmdx = db.CreateCommand();
					cmdx.CommandText = "DELETE FROM tb2";
					cmdx.ExecuteScalar();

					cmdx = db.CreateCommand();
					cmdx.CommandText = "INSERT INTO tb2( pid, name ) values( 1, 'AET' )";
					cmdx.ExecuteScalar();
					cmdx = db.CreateCommand();
					cmdx.CommandText = "INSERT INTO tb2( pid, name ) values( 2, '' )";
					cmdx.ExecuteScalar();
					cmdx = db.CreateCommand();
					cmdx.CommandText = "INSERT INTO tb2( pid, name ) values( 3, '0' )";
					cmdx.ExecuteScalar();


					//[U`֐
					CollationEx collationex = new CollationEx(); 

					//[U`֐o^
					SQLiteCSLib.Inner.ResultEnum rest = db.CreateCollation("D" , collationex);

					IDbCommand cmd = db.CreateCommand();
					cmd.CommandText = "SELECT pid, name FROM tb2 order by name collate D";

					using( IDataReader reader = cmd.ExecuteReader() )
					{
						while( reader.Read() == true )
						{
							object c1 = reader.GetValue( 0 );
							object c2 = reader.GetValue( 1 );

							label1.Text = string.Format(" {0},{1}",c1,c2 );
						}
					}
				}

			}
			catch( Exception ex )
			{
				string mes = ex.Message;
				label1.Text = mes;
			}	
		}

		private void button5_Click(object sender, System.EventArgs e)
		{
			this.sqLiteConnection1.Open();
			

			sqLiteDataAdapter1.Fill( this.dataset11 );

		}
	}
}

==> SQLiteCSLib_Src_1_5.zip: SQLiteCSLib_Src_1_5/1.x/TestApp/TestForm.cs <==
using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;

using SQLiteCSLib;
using SQLiteCSLib.Inner;

namespace TestApp
{
	/// <summary>
	/// CueXgptH[
	/// </summary>
	public class TestForm : System.Windows.Forms.Form
	{
		private System.Windows.Forms.Button button1;
		private System.Windows.Forms.Button button2;
		private System.Windows.Forms.Button button3;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Button button4;
		private System.Windows.Forms.DataGrid dataGrid1;
		private System.Windows.Forms.DataGridTableStyle dataGridTableStyle1;
		private SQLiteCSLib.SQLiteDataAdapter sqLiteDataAdapter1;
		private SQLiteCSLib.SQLiteCommand sqLiteCommand1;
		private SQLiteCSLib.SQLiteConnection sqLiteConnection1;
		private SQLiteCSLib.SQLiteTransaction sqLiteTransaction1;
		private TestApp.Dataset1 dataset11;
		private System.Windows.Forms.Button button5;

		/// <summary>
		/// KvȃfUCiϐłB
		/// </summary>
		private System.ComponentModel.Container components = null;

		/// <summary>
		/// RXgN^
		/// </summary>
		public TestForm()
		{
			InitializeComponent();
		}

		/// <summary>
		/// gpĂ郊\[XɌ㏈s܂B
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows tH[ fUCiŐꂽR[h 
		/// <summary>
		/// fUCi T|[gɕKvȃ\bhłB̃\bh̓e
		/// R[h GfB^ŕύXȂłB
		/// </summary>
		private void InitializeComponent()
		{
			this.button1 = new System.Windows.Forms.Button();
			this.button2 = new System.Windows.Forms.Button();
			this.button3 = new System.Windows.Forms.Button();
			this.label1 = new System.Windows.Forms.Label();
			this.button4 = new System.Windows.Forms.Button();
			this.dataGrid1 = new System.Windows.Forms.DataGrid();
			this.dataset11 = new TestApp.Dataset1();
			this.dataGridTableStyle1 = new System.Windows.Forms.DataGridTableStyle();
			this.sqLiteDataAdapter1 = new SQLiteCSLib.SQLiteDataAdapter();
			this.sqLiteCommand1 = new SQLiteCSLib.SQLiteCommand();
			this.sqLiteConnection1 = new SQLiteCSLib.SQLiteConnection();
			this.sqLiteTransaction1 = new SQLiteCSLib.SQLiteTransaction();
			this.button5 = new System.Windows.Forms.Button();
			((System.ComponentModel.ISupportInitialize)(this.dataGrid1)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.dataset11)).BeginInit();
			this.SuspendLayout();
			// 
			// button1
			// 
			this.button1.Location = new System.Drawing.Point(16, 24);
			this.button1.Name = "button1";
			this.button1.TabIndex = 0;
			this.button1.Text = "button1";
			this.button1.Click += new System.EventHandler(this.button1_Click);
			// 
			// button2
			// 
			this.button2.Location = new System.Drawing.Point(16, 72);
			this.button2.Name = "button2";
			this.button2.TabIndex = 1;
			this.button2.Text = "button2";
			this.button2.Click += new System.EventHandler(this.button2_Click);
			// 
			// button3
			// 
			this.button3.Location = new System.Drawing.Point(120, 24);
			this.button3.Name = "button3";
			this.button3.TabIndex = 2;
			this.button3.Text = "button3";
			this.button3.Click += new System.EventHandler(this.button3_Click);
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(120, 64);
			this.label1.Name = "label1";
			this.label1.TabIndex = 3;
			this.label1.Text = "label1";
			// 
			// button4
			// 
			this.button4.Location = new System.Drawing.Point(16, 128);
			this.button4.Name = "button4";
			this.button4.TabIndex = 4;
			this.button4.Text = "button4";
			this.button4.Click += new System.EventHandler(this.button4_Click);
			// 
			// dataGrid1
			// 
			this.dataGrid1.DataMember = "";
			this.dataGrid1.DataSource = this.dataset11;
			this.dataGrid1.HeaderForeColor = System.Drawing.SystemColors.ControlText;
			this.dataGrid1.Location = new System.Drawing.Point(56, 216);
			this.dataGrid1.Name = "dataGrid1";
			this.dataGrid1.Size = new System.Drawing.Size(376, 160);
			this.dataGrid1.TabIndex = 5;
			this.dataGrid1.TableStyles.AddRange(new System.Windows.Forms.DataGridTableStyle[] {
																								  this.dataGridTableStyle1});
			// 
			// dataset11
			// 
			this.dataset11.DataSetName = "Dataset1";
			this.dataset11.Locale = new System.Globalization.CultureInfo("en-US");
			// 
			// dataGridTableStyle1
			// 
			this.dataGridTableStyle1.DataGrid = this.dataGrid1;
			this.dataGridTableStyle1.HeaderForeColor = System.Drawing.SystemColors.ControlText;
			this.dataGridTableStyle1.MappingName = "";
			// 
			// sqLiteDataAdapter1
			// 
			this.sqLiteDataAdapter1.DeleteCommand = null;
			this.sqLiteDataAdapter1.InsertCommand = null;
			this.sqLiteDataAdapter1.SelectCommand = this.sqLiteCommand1;
			this.sqLiteDataAdapter1.UpdateCommand = null;
			// 
			// sqLiteCommand1
			// 
			this.sqLiteCommand1.CommandText = "select * from tb2";
			this.sqLiteCommand1.CommandTimeout = 0;
			this.sqLiteCommand1.CommandType = System.Data.CommandType.Text;
			this.sqLiteCommand1.Connection = this.sqLiteConnection1;
			this.sqLiteCommand1.Transaction = this.sqLiteTransaction1;
			this.sqLiteCommand1.UpdatedRowSource = System.Data.UpdateRowSource.None;
			// 
			// sqLiteConnection1
			// 
			this.sqLiteConnection1.ConnectionString = "test.sqlite3";
			// 
			// sqLiteTransaction1
			// 
			this.sqLiteTransaction1.Connect = this.sqLiteConnection1;
			// 
			// button5
			// 
			this.button5.Location = new System.Drawing.Point(312, 80);
			this.button5.Name = "button5";
			this.button5.TabIndex = 6;
			this.button5.Text = "button5";
			this.button5.Click += new System.EventHandler(this.button5_Click);
			// 
			// TestForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 12);
			this.ClientSize = new System.Drawing.Size(472, 414);
			this.Controls.Add(this.button5);
			this.Controls.Add(this.dataGrid1);
			this.Controls.Add(this.button4);
			this.Controls.Add(this.label1);
			this.Controls.Add(this.button3);
			this.Controls.Add(this.button2);
			this.Controls.Add(this.button1);
			this.Name = "TestForm";
			this.Text = "Form1";
			((System.ComponentModel.ISupportInitialize)(this.dataGrid1)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.dataset11)).EndInit();
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// {^1
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button1_Click(object sender, System.EventArgs e)
		{
			try
			{
				using( SQLiteConnection db = new SQLiteConnection("test.sqlite3") )
				{
					db.Open();

					string dbversion = db.Database;

					IDbCommand cmd = db.CreateCommand();
					//					cmd.CommandText = "CREATE TABLE tb1 ( pid INTEGER PRIMARY KEY, bin blob )";
					//					object res = cmd.ExecuteScalar();

					/*
										IDbTransaction tran = db.BeginTransaction();

										for( int iIdx=5; iIdx<6; iIdx++ )
										{
											cmd.Parameters.Clear();

											SQLiteParameter idp = cmd.CreateParameter() as SQLiteParameter;
											idp.ParameterName = ":id";
											idp.Value = iIdx;
											idp.Order = 0;
											cmd.Parameters.Add( idp );
											idp = cmd.CreateParameter() as SQLiteParameter;
											idp.ParameterName = ":bin";
											idp.Value = new byte[]{0x01, 0x02, 0x03};
											idp.Order = 1;
											cmd.Parameters.Add( idp );

											cmd.CommandText = "INSERT INTO tb1( pid, bin ) values( ?, ? )";
											cmd.ExecuteNonQuery();
										}

										tran.Commit();
					*/
					cmd.CommandText = "SELECT * FROM tb1 ";

					//					cmd.Parameters.Clear();
					/*
										SQLiteParameter idp = cmd.CreateParameter() as SQLiteParameter;
										idp.Value = "ii";
										idp.Order = 0;
										cmd.Parameters.Add( idp );
					*/

					using( SQLiteDataReader reader = cmd.ExecuteReader() as SQLiteDataReader )
					{
						//						DataTable dt = reader.GetSchemaTable();



						while( reader.Read() == true )
						{
							object c1 = reader.GetValue( 0 );
							object c2 = reader.GetValue( 1 );

							string a1 = reader.GetColumnOriginalName( 0 );
							string a2 = reader.GetColumnDecltype( 0 );

							int a=2;

						}
					}

				}

			}
			catch( Exception ex )
			{
				string mes = ex.Message;
			}
		}

		#region [U`֐eXg

		/// <summary>
		/// XJ[p
		/// </summary>
		protected class ScalarFunc : SQLiteCSLib.Inner.IScalarCallUserFunction
		{
			/// <summary>
			/// ֐R[obN
			/// </summary>
			/// <param name="args"></param>
			public object CallFunc( object[] args )
			{
				foreach( object arg in args )
				{
					if( arg != null )
						Console.Write( arg.ToString() );
				}

				return 1;
			}
		};

		/// <summary>
		/// Wp
		/// </summary>
		protected class AggregateFunc : SQLiteCSLib.Inner.IAggregateCallUserFunction
		{
			/// <summary>
			/// ֐R[obN
			/// </summary>
			/// <param name="args"></param>
			public void CallStep( object[] args )
			{
				foreach( object arg in args )
				{
					if( arg != null )
						Console.Write( arg.ToString() );
				}
			}

			/// <summary>
			/// ֐R[obN
			/// </summary>
			public object CallFinal()
			{
				double dVal = 5.6;

				return dVal;
			}
		};
		#endregion

		/// <summary>
		/// {^2
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button2_Click(object sender, System.EventArgs e)
		{
			label1.Text = "";
			try
			{
				using( SQLiteConnection db = new SQLiteConnection("test.sqlite3") )
				{
					db.Open();

					//[U`֐
					ScalarFunc scalarfunc = new ScalarFunc(); 
					AggregateFunc aggregatefunc = new AggregateFunc();

					//[U`֐o^
					SQLiteCSLib.Inner.ResultEnum rest = db.CreateFunction("SCALAR1", 2, scalarfunc);
					rest = db.CreateFunction("AGGREGATE1", 2, aggregatefunc);

					IDbCommand cmd = db.CreateCommand();
					cmd.CommandText = "SELECT SCALAR1( pid, bin ),AGGREGATE1( 'Ă', null )  FROM tb1 ";

					using( IDataReader reader = cmd.ExecuteReader() )
					{
						while( reader.Read() == true )
						{
							object c1 = reader.GetValue( 0 );
							object c2 = reader.GetValue( 1 );

							label1.Text = string.Format(" {0},{1}",c1,c2 );
						}
					}
				}

			}
			catch( Exception ex )
			{
				string mes = ex.Message;
				label1.Text = mes;
			}		
		}

		/// <summary>
		/// {^3
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button3_Click(object sender, System.EventArgs e)
		{
			try
			{
				using( SQLiteConnection db = new SQLiteConnection("test.sqlite3") )
				{
					db.Open();

					IDbCommand cmd = db.CreateCommand();
					cmd.CommandText = "CREATE TABLE tb1 ( pid INTEGER PRIMARY KEY, bin blob )";
					object res = cmd.ExecuteScalar();
					
					IDbTransaction tran = db.BeginTransaction();

					for( int iIdx=6; iIdx<100; iIdx++ )
					{
						cmd.Parameters.Clear();

						SQLiteParameter idp = cmd.CreateParameter() as SQLiteParameter;
						idp.ParameterName = ":id";
						idp.Value = iIdx;
						idp.Order = 0;
						cmd.Parameters.Add( idp );
						idp = cmd.CreateParameter() as SQLiteParameter;
						idp.ParameterName = ":bin";
						idp.Value = new byte[]{0x01, 0x02, 0x03};
						idp.Order = 1;
						cmd.Parameters.Add( idp );

						cmd.CommandText = "INSERT INTO tb1( pid, bin ) values( ?, ? )";
						cmd.ExecuteNonQuery();
					}

					tran.Commit();
				}

			}
			catch( Exception ex )
			{
				string mes = ex.Message;
			}		
		}

		#region [U`ƍ
		/// <summary>
		/// XJ[p
		/// </summary>
		protected class CollationEx : SQLiteCSLib.Inner.ICollationFunction
		{
			/// <summary>
			/// r
			/// </summary>
			/// <param name="key1">rL[1</param>
			/// <param name="key2">rL[2</param>
			/// <returns> -1,0,1</returns>
			public int Compare( string key1, string key2 )
			{
				if( key1 == "" )
					return 1;

				if( key2 == "" )
					return -1;

				return key1.CompareTo( key2 );
			}
		};

		#endregion

		/// <summary>
		/// {^4
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void button4_Click(object sender, System.EventArgs e)
		{

			label1.Text = "";
			try
			{
				using( SQLiteConnection db = new SQLiteConnection("test.sqlite3") )
				{
					db.Open();

					IDbCommand cmdx = db.CreateCommand();
//					cmdx.CommandText = "CREATE TABLE tb2 ( pid INTEGER PRIMARY KEY, name TEXT )";
//					object res = cmdx.ExecuteScalar();

					cmdx = db.CreateCommand();
					cmdx.CommandText = "DELETE FROM tb2";
					cmdx.ExecuteScalar();

					cmdx = db.CreateCommand();
					cmdx.CommandText = "INSERT INTO tb2( pid, name ) values( 1, 'AET' )";
					cmdx.ExecuteScalar();
					cmdx = db.CreateCommand();
					cmdx.CommandText = "INSERT INTO tb2( pid, name ) values( 2, '' )";
					cmdx.ExecuteScalar();
					cmdx = db.CreateCommand();
					cmdx.CommandText = "INSERT INTO tb2( pid, name ) values( 3, '0' )";
					cmdx.ExecuteScalar();

					long lRowid = db.getLastInsertROWID();


					//[U`֐
					CollationEx collationex = new CollationEx(); 

					//[U`֐o^
					SQLiteCSLib.Inner.ResultEnum rest = db.CreateCollation("D" , collationex);

					IDbCommand cmd = db.CreateCommand();
					cmd.CommandText = "SELECT pid, name FROM tb2 order by name collate D";

					using( IDataReader reader = cmd.ExecuteReader() )
					{
						while( reader.Read() == true )
						{
							object c1 = reader.GetValue( 0 );
							object c2 = reader.GetValue( 1 );

							label1.Text = string.Format(" {0},{1}",c1,c2 );
						}
					}
				}

			}
			catch( Exception ex )
			{
				string mes = ex.Message;
				label1.Text = mes;
			}	
		}

		private void button5_Click(object sender, System.EventArgs e)
		{
			this.sqLiteConnection1.Open();
			

			sqLiteDataAdapter1.Fill( this.dataset11 );

		}
	}
}
